@@ -3,8 +3,8 @@ from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 class AbstractEventConfiguration(AbstractRelationTime):
 
-    event_id = models.IntegerField()
-    value = models.JSONField()
+    event_id = models.IntegerField(verbose_name='活动id')
+    value = models.JSONField(verbose_name='内容')
 
     class Meta:
         abstract = True
