@@ -61,7 +61,7 @@ class FrontendView:
         res = App(appid).qrcode.get_url(result['ticket'])
         path = f"event/qrcode-official-account/{scene_str}.jpg"
         OSS.put_object_internet(res, path)
-        url = f"https://{settings.BLUEDOT_REST_FRAMEWORK['UTILS']['OSS']['bucket_name']}.oss-cn-beijing.aliyuncs.com/{path}"
+        url = f"https://{settings.BLUEDOT_REST_FRAMEWORK['utils']['OSS']['bucket_name']}.oss-cn-beijing.aliyuncs.com/{path}"
         return Response({'url': url})
 
     # @action(detail=False, methods=['get'], url_path='share-qrcode-miniprogram', url_name='share-qrcode-miniprogram')
