@@ -2,8 +2,8 @@ import os
 from datetime import datetime
 from rest_framework.decorators import action
 from rest_framework.response import Response
-from project.utils.vhall import Vhall
-from project.utils.func import md5_str
+from bluedot_rest_framework.utils.vhall import Vhall
+from bluedot_rest_framework.utils.func import md5_str, orm_bulk_update
 from .models import EventLivePPT
 from .ppt import ppt2images
 
@@ -15,19 +15,31 @@ class LiveView:
         _id = request.data.get('event_id', None)
         room_id = Vhall.room_create()
         quesyset = self.model_class.objects.get(pk=_id)
-        quesyset.live_room_id = room_id
-        quesyset.live_create_room_time = datetime.now()
-        quesyset.save()
+        update_dict = {
+            'live_room_id': room_id,
+            'live_create_room_time': datetime.now(),
+        }
+        if quesyset.live_type == 2:
+            update_dict['live_inav'] = {'id': Vhall.create_inav()}
+        orm_bulk_update(quesyset, update_dict)
         return Response({'room_id': room_id})
 
+    @action(detail=False, methods=['post'], url_path='live-room-inav-push', url_name='live-room-inav-push', permission_classes=[])
+    def live_room_inav_push(self, request, *args, **kwargs):
+        _id = request.data.get('event_id', None)
+        quesyset = self.model_class.objects.get(pk=_id)
+        Vhall.push_inav(
+            inav_id=quesyset.live_inav['id'], room_id=quesyset.live_room_id)
+        return Response()
+
     @action(detail=False, methods=['get'], url_path='live-room-token', url_name='live-room-token')
     def live_room_token(self, request, *args, **kwargs):
-        live_room_id = request.query_params.get('id', None)
+        live_room_id = request.query_params.get('live_room_id', None)
+        live_inav_id = request.query_params.get('inav_id', None)
         third_party_user_id = request.query_params.get(
             'third_party_user_id', None)
         token = Vhall.get_token(
-            room_id=live_room_id, third_party_user_id=third_party_user_id)
-
+            room_id=live_room_id, third_party_user_id=third_party_user_id, live_inav_id=live_inav_id)
         return Response({'token': token})
 
     @action(detail=False, methods=['post'], url_path='live-room-delete', url_name='live-room-delete')
@@ -62,8 +74,11 @@ class LiveView:
                                start_time=start_time,
                                end_time=end_time)
         if vod:
-            queryset.update(
-                live_playback=1, live_vod_id=vod['live_vod_id'], live_task_id=vod['live_task_id'])
+            orm_bulk_update(quesyset, {
+                'live_playback': 1,
+                'live_vod_id': vod['vod_id'],
+                'live_task_id': vod['task_id'],
+            })
             return Response({'code': 1})
         return Response({'code': 0})
 
