@@ -3,13 +3,13 @@ from .abstract_models import AbstractEventExtend, AbstractEventLive, AbstractEve
 
 
 class AbstractEvent(AbstractEventExtend, AbstractEventLive, AbstractEventAddress, AbstractRelationTime):
-    event_type = models.IntegerField(default=1)
+    event_type = models.IntegerField(default=1, verbose_name='活动类型')
     is_show = models.IntegerField(default=0)
 
-    title = models.CharField(max_length=255)
-    sub_title = models.CharField(max_length=255, null=True)
+    title = models.CharField(max_length=255, verbose_name='标题')
+    sub_title = models.CharField(max_length=255, null=True, verbose_name='副标题')
     description = models.TextField(verbose_name='介绍')
-
+    duration = models.IntegerField(default=0, verbose_name='持续时间')
     banner = models.CharField(max_length=255, verbose_name='封面图片')
     qr_code = models.CharField(max_length=255, verbose_name='二维码', null=True)
     start_time = models.DateTimeField(verbose_name='开始时间')
