@@ -4,6 +4,7 @@ from bluedot_rest_framework import import_string
 
 
 Event = import_string('event.models')
+EventRegisterConfig = import_string('event.register.config_models')
 EventRegister = import_string('event.register.models')
 
 
@@ -12,6 +13,7 @@ class EventRegisterSerializer(CustomSerializer):
     user_id = IntegerField(required=False)
     unionid = CharField(required=False)
     openid = CharField(required=False)
+    country = CharField(required=False)
     wechat_id = IntegerField(required=False)
 
     class Meta:
@@ -28,3 +30,10 @@ class EventRegisterSerializer(CustomSerializer):
             "end_time": event_queryset.end_time,
             "banner": event_queryset.banner
         }
+
+
+class EventRegisterConfigSerializer(CustomSerializer):
+
+    class Meta:
+        model = EventRegisterConfig
+        fields = '__all__'
