@@ -6,12 +6,12 @@ class AbstractEventSchedule(AbstractRelationTime):
 
     project_title = models.CharField(max_length=255, verbose_name='项目名称')
     topic_title = models.CharField(max_length=255, verbose_name='互动话题名称')
-    start_time = models.DateTimeField()
-    end_time = models.DateTimeField()
+    start_time = models.DateTimeField(verbose_name='开始时间')
+    end_time = models.DateTimeField(verbose_name='结束时间')
 
-    sort = models.IntegerField(default=0)
+    sort = models.IntegerField(default=0, verbose_name='排序')
 
-    speaker_ids = models.JSONField(null=True)
+    speaker_ids = models.JSONField(null=True, verbose_name='演讲嘉宾')
 
     class Meta:
         abstract = True
