@@ -3,16 +3,16 @@ from bluedot_rest_framework.question.abstract_models import AbstractQuestion, Ab
 
 
 class EventVote(AbstractQuestion):
-    event_id = models.IntegerField()
-    schedule_id = models.IntegerField()
-    state = models.IntegerField(default=0)
+    event_id = models.IntegerField(verbose_name='活动id')
+    schedule_id = models.IntegerField(verbose_name='日程id')
+    state = models.IntegerField(default=0, verbose_name='状态')
 
     class Meta:
         db_table = 'event_vote'
 
 
 class EventVoteUser(AbstractQuestionUser):
-    schedule_id = models.IntegerField(default=0)
+    schedule_id = models.IntegerField(default=0, verbose_name='日程id')
 
     class Meta:
         db_table = 'event_vote_user'
