@@ -2,8 +2,8 @@ from bluedot_rest_framework.utils.serializers import CustomSerializer
 from bluedot_rest_framework import import_string
 from rest_framework.serializers import CharField, IntegerField
 
-EventVote = import_string('EVENT.vote.models')
-EventVoteUser = import_string('EVENT.vote.user_models')
+EventVote = import_string('event.vote.models')
+EventVoteUser = import_string('event.vote.user_models')
 
 
 class EventVoteSerializer(CustomSerializer):
