@@ -14,7 +14,6 @@ EventVoteUserSerializer = import_string('event.vote.user_serializers')
 class EventVoteView(CustomModelViewSet):
     model_class = EventVote
     serializer_class = EventVoteSerializer
-    pagination_class = None
 
     filterset_fields = {
         'event_id': {
@@ -32,8 +31,8 @@ class EventVoteView(CustomModelViewSet):
     }
 
     def create(self, request, *args, **kwargs):
-        event_id = self.request.data.get('event_id', None)
-        queryset = self.model_class.objects.filter(event_id=event_id).first()
+        schedule_id = self.request.data.get('schedule_id', None)
+        queryset = self.model_class.objects.filter(schedule_id=schedule_id).first()
         if queryset:
             partial = kwargs.pop('partial', False)
             serializer = self.get_serializer(
@@ -48,12 +47,7 @@ class EventVoteView(CustomModelViewSet):
             headers = self.get_success_headers(serializer.data)
             return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
 
-    def list(self, request, *args, **kwargs):
-        schedule_id = request.query_params.get('schedule_id', None)
-        queryset = self.model_class.objects.filter(
-            schedule_id=schedule_id).first()
-        serializer = self.get_serializer(queryset)
-        return Response(serializer.data)
+
 
 
 class EventVoteUserView(CustomModelViewSet):
@@ -61,8 +55,14 @@ class EventVoteUserView(CustomModelViewSet):
     serializer_class = EventVoteUserSerializer
 
     filterset_fields = {
-        'event_id': ['exact'],
-        'schedule_id': ['exact'],
+        'event_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
+        'schedule_id': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        },
     }
 
     def create(self, request, *args, **kwargs):
