@@ -24,9 +24,11 @@ class MaterialSerializer(CustomSerializer):
                     data.append({'id': str(instance.id), '_type': 5,
                                  'title': instance.title, 'created': instance.created})
                 else:
-                    instance = self.Meta.model.objects.get(pk=item.material_id)
-                    data.append({'id': str(instance.pk), '_type': instance._type,
+                    instance = self.Meta.model.objects.get(
+                        pk=item['material_id'])
+                    data.append({'id': str(instance.id), '_type': instance.material_type,
                                  'title': instance.title, 'created': instance.created})
+
         except:
             pass
         return data
