@@ -88,6 +88,11 @@ DEFAULTS_SETTINGS = {
         'models': 'bluedot_rest_framework.material.models.Material',
         'serializers': 'bluedot_rest_framework.material.serializers.MaterialSerializer',
         'views': 'bluedot_rest_framework.material.views.MaterialView',
+        'tags': {
+            'models': 'bluedot_rest_framework.material.tags.models.Tags',
+            'serializers': 'bluedot_rest_framework.material.tags.serializers.TagsSerializer',
+            'views': 'bluedot_rest_framework.material.tags.views.TagsView',
+        },
     },
     'question': {
         'models': 'bluedot_rest_framework.question.models.Question',
@@ -116,6 +121,10 @@ DEFAULTS_SETTINGS = {
         'user_views': 'bluedot_rest_framework.data_download.views.DataDownloadUserView',
     },
     'wechat': {
+        'qrcode': {
+            'models': 'bluedot_rest_framework.wechat.response.models.WeChatQrcode',
+            'serializers': 'bluedot_rest_framework.wechat.response.serializers.WeChatQrcodeSerializer',
+        },
         'response': 'bluedot_rest_framework.wechat.response.response.Response',
         'models': 'bluedot_rest_framework.wechat.models.WeChatUser',
         'miniprogram': {
