@@ -14,14 +14,13 @@ def jwt_response_payload_handler_admin(token, user=None, request=None):
     }
 
 
-def jwt_payload_handler_wehat(wechat_id, unionid):
+def jwt_payload_handler_wehat(userid, wechat_id, unionid):
     payload = {
         'user_id': settings.JWT_AUTH['SUPERUSER_ID'],
         'username': settings.JWT_AUTH['SUPERUSER_NAME'],
-        # 'openid': openid,
         'unionid': unionid,
-        # 'userid': userid,
         'wechat_id': wechat_id,
+        'userid': userid,
         'exp': datetime.now() + api_settings.JWT_EXPIRATION_DELTA
     }
     if api_settings.JWT_ALLOW_REFRESH:
@@ -39,9 +38,19 @@ def jwt_create_token_wechat(wechat_id, unionid=''):
     """
     创建token
     """
+    userid = ''
     jwt_encode_handler = api_settings.JWT_ENCODE_HANDLER
+    payload = jwt_payload_handler_wehat(userid, wechat_id, unionid)
+    token = jwt_encode_handler(payload)
+    return token
 
-    payload = jwt_payload_handler_wehat(wechat_id, unionid)
+
+def jwt_create_token_pc(userid, wechat_id='', unionid=''):
+    """
+    创建token
+    """
+    jwt_encode_handler = api_settings.JWT_ENCODE_HANDLER
+    payload = jwt_payload_handler_wehat(userid, wechat_id, unionid)
     token = jwt_encode_handler(payload)
     return token
 
@@ -74,6 +83,10 @@ def jwt_get_wechatid_handler(token):
     return jwt_decode_handler_wechat(token)['wechat_id']
 
 
+def jwt_get_userid_handler(token):
+    return jwt_decode_handler_wechat(token)['userid']
+
+
 def jwt_get_userinfo_handler(token):
     return jwt_get_wechatid_handler(token), jwt_get_unionid_handler(token)
 
