@@ -11,6 +11,9 @@ class WeChatUserSet:
     appid = ''
     openid = ''
 
+    user_data = None  # 用户信息
+    wechat_user_queryset = None  # WeChatUser QuerySet
+
     def __init__(self, appid, user_info=None, openid=None):
         self.appid = appid
         if user_info or openid:
@@ -26,22 +29,43 @@ class WeChatUserSet:
                     'language': user_info.get('language', '')
                 }
                 self.openid = user_info.get('openid', '')
+                self.wechat_user_queryset = WeChatUser.objects.filter(
+                    unionid=self.user_data['unionid']).first()
+                self.handle_user()
             else:
                 self.openid = openid
-                user_info = App(self.appid).user.get(self.openid)
-                self.__init__(appid=self.appid, user_info=user_info)
-            self.wechat_user_queryset = WeChatUser.objects.filter(
-                unionid=self.user_data['unionid']).first()
-            self.handle_user()
+                try:
+                    user_info = App(self.appid).user.get(self.openid)
+                    self.__init__(appid=self.appid, user_info=user_info)
+                    unionid = self.user_data['unionid']
+                    self.wechat_user_queryset = WeChatUser.objects.filter(
+                        unionid=unionid).first()
+                    self.handle_user()
+                except:
+                    wechat_user_openid_queryset = WeChatUserOpenid.objects.filter(
+                        openid=openid).first()
+                    if wechat_user_openid_queryset:
+                        queryset = WeChatUser.objects.filter(
+                            pk=wechat_user_openid_queryset.wechat_id).first()
+                        if queryset:
+                            self.wechat_user_queryset = WeChatUser.objects.filter(
+                                unionid=queryset.unionid).first()
+                    pass
 
     def create_user(self):
-        user = App(self.appid).user.get(self.openid)
+        subscribe = 0
+        try:
+            user = App(self.appid).user.get(self.openid)
+            subscribe = user['subscribe']
+        except:
+            pass
+
         self.wechat_user_queryset = WeChatUser.objects.create(**self.user_data)
         openid_data = {
             'wechat': self.wechat_user_queryset,
             'appid': self.appid,
             'openid': self.openid,
-            'subscribe': user['subscribe']
+            'subscribe': subscribe
         }
         WeChatUserOpenid.objects.create(**openid_data)
 
@@ -55,6 +79,8 @@ class WeChatUserSet:
             self.create_user()
 
     def get_token(self):
-        token = jwt_create_token_wechat(wechat_id=self.wechat_user_queryset.pk,
-                                        unionid=self.wechat_user_queryset.unionid)
+        token = ''
+        if self.wechat_user_queryset:
+            token = jwt_create_token_wechat(wechat_id=self.wechat_user_queryset.pk,
+                                            unionid=self.wechat_user_queryset.unionid)
         return token
